import csv
from io import TextIOWrapper
from config import item_attributes

def get_csv_data(file):
    csv_file = TextIOWrapper(file, encoding='utf-8')
    reader = csv.DictReader(csv_file, delimiter='|')

    # Validate CSV headers based on config
    required_headers = set(item_attributes.keys())  # Get required headers as per configuration
    csv_headers = set(reader.fieldnames)    # Get headers present in the csv file

    # Check if the required headers exist
    if not required_headers.issubset(reader.fieldnames):
        raise ValueError(f"CSV file must include headers: {', '.join(required_headers)}.")
    
    # Check for invalid headers
    if extra_headers := csv_headers - valid_headers:
        raise ValueError(f"Unexpected headers found: {', '.join(extra_headers)}")

    # Extract data dynamically based on config
    return [{attrib: row[attrib] for attrib in item_attributes} for row in reader]
